#!/usr/bin/perl -w
####################################################################
###
### script name: Create_AcousticModel.pl
### modified by: Ken MacLean
### email: contact@voxforge.org
### Date: 2006.07.29
### Command: ./Create_AcousticModel.pl
### Version: 0.1
###		
### Copyright (C) 2006 Ken MacLean
###
### This program is free software; you can redistribute it and/or
### modify it under the terms of the GNU General Public License
### as published by the Free Software Foundation; either version 2
### of the License, or (at your option) any later version.
###
### This program is distributed in the hope that it will be useful,
### but WITHOUT ANY WARRANTY; without even the implied warranty of
### MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
### GNU General Public License for more details.
###
####################################################################
# input files
####################################################################
# update these files:
#   FilesToBeConverted2mfc
#   FilesToBeDownsampled

####################################################################
# external packages
####################################################################
#use strict; # have not tried this yet
use File::Spec;

####################################################################
# Variables
####################################################################
$audio_dir_name = "an4";
$original_audio_rate_dir = "16kHz:16bit";
$original_sampling_rate = 16000; # only used for svn property update
$original_bits_per_sample = 16; # only used for svn property update!
$original_file_type = 'raw'; # used for downsampling script and svn rename!
$dialect = "US English";

$target_audio_rate_dir = "16kHz:16bit";
$downsample_rate = 16000;
$downsample_bits_per_sample = 16; # only used for svn property update!

#!!!!!! need to change to use relative paths
$path_original = "/home/kmaclean/workspace/VoxForge/Audio/Original/$original_audio_rate_dir";

$path_main = "/home/kmaclean/workspace/VoxForge/Audio/Main/$target_audio_rate_dir";
$filestobedownsampled = "FilesToBeDownsampled";
# commit original license file and rename it so that this script can work ... 
$license_file_original = "an4-LICENSE"; # note: original and target cannot have the same name - svn fails with a "cannot move path onto itsef error"
$license_file_target = "LICENSE";

#$prompts_file_original = "etc/com.data";
#$prompts_file_target = "etc/prompts";

$path_mfcc = "/home/kmaclean/workspace/VoxForge/Audio/MFCC/$target_audio_rate_dir/MFCC_0_D";
$HTK_ParameterKindWithQualifiers = "MFCC_0_D"; # only used for svn property update!


$debug = 1;

####################################################################
# Main
####################################################################
# A. SUBMIT AUDIO
####################################################################
# completed when creating 8kHz:16-bit Acoustic Models
####################################################################
# B. Downsample Audio
####################################################################    
   

####################################################################
# C. Create MFCCs
####################################################################    
    
# 12a. copy audio files from Original directory to Main directory
print "\ndbg_12a: svn copy $path_main\/$audio_dir_name, $path_mfcc\/$audio_dir_name\n" if $debug;
@command = ("svn", "copy", "$path_main\/$audio_dir_name", "$path_mfcc\/$audio_dir_name" );
   system(@command) == 0 or die "system @command failed: $?";   

	# 12b. Update: seem to need an update to 'update' the working copy before executing the commit to repository
	print "\ndbg_12b: svn update -r HEAD $path_mfcc\/$audio_dir_name\n" if $debug;
	@command = ("svn", "update", "-r", "HEAD", "$path_mfcc\/$audio_dir_name"  );
	   system(@command) == 0 or die "system @command failed: $?";  
	          
	# 12c. Commit: Commit copy of audio      
	print "\ndbg_12c: svn commit $audio_dir_name, -N, $path_mfcc\/$audio_dir_name\n" if $debug;
	@command = ("svn", "commit", "-m", "copied $audio_dir_name wav files to MFCC directory", 
	            "$path_mfcc\/$audio_dir_name"  );
	   system(@command) == 0 or die "system @command failed: $?";         

# 13a. rename     
# move /home/kmaclean/workspace/test/Audio/Main/8kHz:16bit/cmu_us_liam_arctic/wav /home/kmaclean/workspace/test/Audio/Main/8kHz:16bit/cmu_us_liam_arctic/mfc
print "\ndbg_13a: svn move $path_mfcc\/$audio_dir_name\/wav $path_mfcc\/$audio_dir_name\/mfc\n" if $debug;
@command = ("svn", "move", "$path_mfcc\/$audio_dir_name\/wav", "$path_mfcc\/$audio_dir_name\/mfc"  );
   system(@command) == 0 or die "system @command failed: $?";         

	# 13b. Update: seem to need an update to 'update' the working copy before executing the commit to repository
	print "\ndbg_13b: svn update -r HEAD $path_mfcc\/$audio_dir_name\n" if $debug;
	@command = ("svn", "update", "-r", "HEAD", "$path_mfcc\/$audio_dir_name"  );
	   system(@command) == 0 or die "system @command failed: $?";  
	     
	# 13c. Commit rename 
	   print "\ndbg_13c: svn commit $audio_dir_name, -N, $path_mfcc\/$audio_dir_name\n" if $debug;
	@command = ("svn", "commit", "-m", "renamed $audio_dir_name wav directory to mfc", 
	            "$path_mfcc\/$audio_dir_name"  );
	   system(@command) == 0 or die "system @command failed: $?";         
	     
# 14 Convert wav audio to HTK mfcc script      
# ./ConvertWav2mfc.pl FilesToBeConverted2mfc
print "\ndbg_14: ./ConvertWav2mfc.pl FilesToBeConverted2mfc\n" if $debug;
@command = ("./ConvertWav2mfc.pl", FilesToBeConverted2mfc);
   system(@command) == 0 or die "system @command failed: $?";      
     
# 15a. update properties
print "\ndbg_15a: propset -R HTK_ParameterKindWithQualifiers  $HTK_ParameterKindWithQualifiers\n" if $debug;
 @command = ("svn", "propset", "-R", "HTK_ParameterKindWithQualifiers", $HTK_ParameterKindWithQualifiers, "$path_mfcc\/$audio_dir_name"  );
   system(@command) == 0 or die "system @command failed: $?";    
	
	# 15b. Commit: Commit conversion to mfcc and property update 
	print "\ndbg_15b: svn update\n" if $debug;
	@command = ("svn", "update", "-r", "HEAD", $path_mfcc );
	   system(@command) == 0 or die "system @command failed: $?";  
     
	print "\ndbg_15c: svn commit $audio_dir_name, -N, $path_mfcc\/$audio_dir_name\n" if $debug;
	@command = ("svn", "commit", "-m", "$audio_dir_name wav files converted to HTK mfc & updated properties", 
	            "$path_mfcc\/$audio_dir_name"  );
	   system(@command) == 0 or die "system @command failed: $?";  
     
####################################################################
# C. Create Acoustic Model
####################################################################              
# 22. compile Acoustic Model
# fix prompts file first!!!
#print "\ndbg_22: ./Compile_AcousticModel.sh\n" if $debug;
#@command = ("./Compile_AcousticModel.sh");
#   system(@command) == 0 or die "system @command failed: $?";      
     
     
print "\nCompleted!\n" if $debug;     
     
     